Changelog
=========

0.2 (2013-02-07)
----------------

- Handle custom server-side search implementation
- Handle custom server-side sort implementation


0.1.2 (2013-02-07)
------------------

- Fix static files packaging


0.1.1 (2013-02-07)
------------------

- Fix requirements packaging


0.1 (2013-02-07)
----------------

- Initial implementation
